import json
import os
import time
import argparse
from Utility import Utility, RunEnv, PolicyService


class BootstrapDefaultPolicies:
    POLICY_EXISTS = 'Policy Id is already present'
    SUCCESS = 'Success'

    def __init__(self):
        parser = argparse.ArgumentParser(
            description="Given a path to an bootstrap sequence file, load the policies "
                        "listed in the bootstrap sequence file.")
        parser.add_argument('-u', help='The complete URL to the Policy Service.',
                            default=None)
        arguments = parser.parse_args()
        if arguments.u is not None:
            RunEnv.POLICY_SERVICE_URL = arguments.u
        if RunEnv.POLICY_SERVICE_URL is None:
            exit('The policy service URL is not specified')
        self.url = RunEnv.POLICY_SERVICE_URL
        print('Current data-partition-id: {}'.format(RunEnv.DATA_PARTITION))
        ok, error_mess = RunEnv().is_ok()
        if not ok:
            exit('Error: environment setting incomplete: {}'.format(error_mess))

    def create_policies(self):
        info = list()
        errors = list()
        deployments = Utility.path_to_deployments()
        start = time.time()

        sequence = Utility.load_json(os.path.join(deployments, RunEnv.POLICIES_FOLDER, RunEnv.BOOTSTRAP_SEQUENCE))
        policy_service = PolicyService(self.url)
        for item in sequence:
            policy_content=Utility.load_rego(os.path.join(deployments, item['relativePath']))
            policy_service.put_policy(item['id'], policy_content, info, errors) 

        elapsed = time.time() - start
        print('This update took {:.2f} seconds.'.format(elapsed))
        if len(info) != 0:
            print('Following policies were created or already existed:')
            print('\n'.join(info))
        if len(errors) != 0:
            print('Following policies were not created:')
            print('\n'.join(errors))
            exit(1)
        else:
            print('No errors during bootstraping of all {} policies'.format(str(len(sequence))))


if __name__ == '__main__':
    BootstrapDefaultPolicies().create_policies()
